@@ -111,6 +111,10 @@ extern "C" {
  */
 - (NSData*) decodeBase64From: (NSString*)str;
 
+/** Decode the supplied base64url encoded data and return the result.
+ */
+- (NSData*) decodeBase64UrlFrom: (NSString*)str;
+
 /** Decode the supplied hexBinary encoded data and return the result.<br />
  * This is a tolerant parser, it accepts lower case hex digits and white
  * space, but it does insist on an even number of hexadecimal digits.<br />
@@ -122,6 +126,10 @@ extern "C" {
  */
 - (NSString*) encodeBase64From: (NSData*)source;
 
+/** Take the supplied data and convert it to base64url encoded text.
+ */
+- (NSString*) encodeBase64UrlFrom: (NSData*)source;
+
 /** Encode the supplied data as hexBinary data in the canonical form
  * (as per W3 schema recommendations) and return the result.<br />
  * The canonical form uses upper case hexadecimal digits.
@@ -421,6 +429,7 @@ typedef enum {
  */
 @interface GWSXMLRPCCoder : GWSCoder
 {
+  BOOL  _strictParsing;
 }
 /** Builds a simple fault response.
  */
@@ -432,6 +441,15 @@ typedef enum {
  */
 - (NSString*) encodeDateTimeFrom: (NSDate*)source;
 
+/** Sets whether parsing requires strict use of plain XML elements,
+ * or permits attributes and namespaces to be attached to them (and ignored).
+ */
+- (void) setStrictParsing: (BOOL)isStrict;
+
+/** Returns whether parsing requires strict use of plain XML elements,
+ * or permits attributes and namespaces to be attached to them (and ignored).
+ */
+- (BOOL) strictParsing;
 @end
 
 /** <p>The GWSJSONCoder class is a concrete subclass of [GWSCoder] which
@@ -508,8 +526,9 @@ typedef enum {
  * If an encoding order is specified (or if the RPC version is 1.0) then
  * the encoded result is an array and parameters are passed by position
  * as items in that array.<br />
- * Otherwise, if there is a single parameter whose name is GWSJSONResult,
- * then that parameter is encoded as the result.<br />
+ * Otherwise, if there is a single parameter whose name is the constant
+ * GWSJSONResultKey (the string 'GWSJSONResult'), then that parameter
+ * parameter is encoded as the result.<br />
  * Otherwise the encoded result is an object, and the parameters are passed
  * by name (as fields in that object).
  * </p>
